==> haskell-unicode-transforms-0.3.4-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.3.4
id: unicode-transforms-0.3.4-1rg0g2UsoWt5PXZgS3OzXu
key: unicode-transforms-0.3.4-1rg0g2UsoWt5PXZgS3OzXu
license: BSD-3-Clause
copyright: 2016-2017 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
author: Harendra Kumar
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 9.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
abi: bd3fde7f58feb554a80f3c7f8ee2f833
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
import-dirs: /usr/lib/ghc-8.6.1/site-local/unicode-transforms-0.3.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/unicode-transforms-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/unicode-transforms-0.3.4
hs-libraries: HSunicode-transforms-0.3.4-1rg0g2UsoWt5PXZgS3OzXu
depends:
    base-4.12.0.0 bitarray-0.0.1.1-EskIcqtb5tWIkqUWAsqhuT
    bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.3.5-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.3.5
id: unicode-transforms-0.3.5-Fz3EZHFdCO2JA30k1ZdjUR
key: unicode-transforms-0.3.5-Fz3EZHFdCO2JA30k1ZdjUR
license: BSD-3-Clause
copyright: 2016-2017 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
author: Harendra Kumar
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 9.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
abi: dca64311b3d97b928e78cf92a1d30c50
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
import-dirs: /usr/lib/ghc-8.6.3/site-local/unicode-transforms-0.3.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/unicode-transforms-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/unicode-transforms-0.3.5
hs-libraries: HSunicode-transforms-0.3.5-Fz3EZHFdCO2JA30k1ZdjUR
depends:
    base-4.12.0.0 bitarray-0.0.1.1-57fm9u9YqCN6DKImkqvkn0
    bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
